# frozen_string_literal: true

RSpec.describe "Request logging", type: :request do
  before :each do
    Ramverk.configure do |config|
      config.mount ->(_) { [200, {}, ["Hello"]] }, at: "/", as: :test
      config.logger = Logger.new($stdout)
    end
  end

  def app
    Ramverk.rack
  end

  it "log request information" do
    msg = Regexp.escape(%([200] GET '/books' for 127.0.0.1 in))

    expect { get "/books" }
      .to output(/#{msg}/).to_stdout_from_any_process
  end

  it "filter out sensitive data" do
    Ramverk.configuration.logger = Logger.new("spec/tmp/formatter.log")

    get "/books?session[password]=secret"

    data = File.read("spec/tmp/formatter.log").split("\n").last
    message = JSON.parse(data)["message"]

    expect(message)
      .to include(%(with {"session"=>{"password"=>"[FILTERED]"}}))
  end
end
