# frozen_string_literal: true

RSpec.describe "Serve static files", type: :request do
  before :each do
    Ramverk.configure do |config|
      config.serve_static_files = true
      config.public_directory = "spec/fixtures/files"

      config.mount ->(env) { [200, {}, ["Hello World"]] }, at: "/", as: :test
    end
  end

  def app
    Ramverk.rack
  end

  it "serves static files" do
    get "/example.txt"

    expect(last_response.headers["Content-Type"])
      .to eq("text/plain")
    expect(last_response.body)
      .to eq("Hello from example.txt")
  end

  it "serves mounted apps if file not found" do
    get "/unknown.txt"

    expect(last_response.body)
      .to eq("Hello World")
  end
end
