# frozen_string_literal: true

require "ramverk/cli/command"

module RSpec
  module Support
    module Cli
      module_function

      def ramverk(*args)
        Ramverk::Cli::Command.start(args)
      end

      def supress
        original_stderr = $stderr.clone
        original_stdout = $stdout.clone
        $stderr.reopen(File.new(IO::NULL, "w"))
        $stdout.reopen(File.new(IO::NULL, "w"))
        yield
      ensure
        $stdout.reopen(original_stdout)
        $stderr.reopen(original_stderr)
      end

      def with_env(env)
        original_env = ENV["APP_ENV"]
        ENV["APP_ENV"] = env.to_s
        yield
      ensure
        ENV["APP_ENV"] = original_env
      end

      def with_project_structure
        project_name = "test_project_#{Time.now.to_i}"
        original_dir = Dir.pwd

        Dir.chdir "spec/tmp" do
          supress { ramverk "new", project_name }

          Dir.chdir project_name do
            Ramverk.configuration.root = Dir.pwd

            yield
          end
        end
      ensure
        Dir.chdir(original_dir)
      end
    end
  end
end

RSpec.configure do |config|
  config.include RSpec::Support::Cli, type: :cli
end
