# frozen_string_literal: true

RSpec.describe Ramverk do
  it "has a version number" do
    expect(Ramverk::VERSION)
      .to be_a(String)
  end

  describe ".env" do
    it "return the current environment status" do
      expect(Ramverk.env)
        .to eq(:test)
    end
  end

  describe ".env?" do
    it "returns true if environment(s) match" do
      expect(Ramverk.env?(:test))
        .to be(true)
      expect(Ramverk.env?(:development, :test))
        .to be(true)
      expect(Ramverk.env?(:development))
        .to be(false)
      expect(Ramverk.env?(:staging, :production))
        .to be(false)
    end
  end

  describe ".configure" do
    it "yields the configuration object" do
      Ramverk.configure do |config|
        expect(config)
          .to be_a(Ramverk::Configuration)
        expect(config)
          .to eq(Ramverk.configuration)
      end
    end
  end

  describe ".rake?" do
    it "returns false if not run by rake" do
      expect(Ramverk.rake?)
        .to be(false)
    end

    it "returns true if run by rake" do
      previous_program = $PROGRAM_NAME
      $PROGRAM_NAME = "/path/to/rake"

      expect(Ramverk.rake?)
        .to be(true)

      $PROGRAM_NAME = previous_program
    end
  end
end
